@@ -3,7 +3,7 @@
 #' \code{Existy()} returns TRUE or FALSE if an object exists or not.
 #' An object exists if it is not NULL or NA.
 #'
-#' @param x an object.
+#' @param .x an object.
 #' @return a logical value.
 #' @family predicate functions
 #' @examples
@@ -23,6 +23,6 @@
 #' # Works with applying over lists
 #' lapply(list(4, "foo", NULL, NA), Existy) # TRUE, TRUE, FALSE, FALSE
 #' @export
-Existy <- function(x) {
-  return(!is.null(x) && !is.na(x))
+Existy <- function(.x) {
+  return(!is.null(.x) && !is.na(.x))
 }
