@@ -2,12 +2,12 @@
 #'
 #' Wrapper for \code{\link[base]{lapply}}.
 #'
-#' @param f a function.
-#' @param x a value.
-#' @param ... optional arguments to f.
+#' @param .x A vector.
+#' @param .f A function to be applied.
+#' @param ... Optional arguments to .f.
 #' @family functionals
 #' @seealso \code{\link[base]{lapply}} for code and documentation.
 #' @export
-Lapply <- function(f, x, ...) {
-  return(lapply(X = x, FUN = f, ...))
+Lapply <- function(.x, .f, ...) {
+  return(lapply(X = .x, FUN = .f, ...))
 }
