@@ -7,15 +7,10 @@ foo <- list(NA_integer_, TRUE, NA_character_, 1, NULL,
 bar <- c(FALSE, TRUE, FALSE, TRUE, FALSE,
          TRUE, FALSE, TRUE, TRUE, FALSE)
 
-test_that("Existy() returns values of type 'logical'", {
-  expect_is(unlist(Lapply(Existy, foo)), "logical")
-})
-
-test_that("Existy() returns TRUE if an object 'exists'", {
-  expect_equal(unlist(Lapply(Existy, foo)), bar)
+test_that("Produces the correct output.", {
+  expect_equal(unlist(lapply(foo, Existy)), bar)
   expect_equal(Existy(NULL), FALSE)
   expect_equal(Existy(NA), FALSE)
-  expect_warning(Existy(Existy), "is.na() applied to non-(list or vector) of type 'closure'", fixed = TRUE)
   expect_equal(Existy(1), TRUE)
   expect_equal(Existy(2.4), TRUE)
   expect_equal(Existy("hello"), TRUE)
@@ -23,3 +18,16 @@ test_that("Existy() returns TRUE if an object 'exists'", {
   expect_equal(Existy(TRUE), TRUE)
 })
 
+test_that("Produces the correct output type.", {
+  expect_is(Existy(NULL), "logical")
+  expect_is(Existy(NA), "logical")
+  expect_is(Existy(1), "logical")
+  expect_is(Existy(2.4), "logical")
+  expect_is(Existy("hello"), "logical")
+  expect_is(Existy(FALSE), "logical")
+  expect_is(Existy(TRUE), "logical")
+})
+
+test_that("Produces the correct errors.", {
+  expect_warning(Existy(Existy), "is.na() applied to non-(list or vector) of type 'closure'", fixed = TRUE)
+})
